Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: src/tools/flashtool/main.cc

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/tools/flashtool/main.cc
diff --git a/src/tools/flashtool/main.cc b/src/tools/flashtool/main.cc
index 025609764f7fc8a228423e38b2c6f0aac5f0477d..a362c50f503ec64bd2b988ce8faf3ed980659bd3 100644
--- a/src/tools/flashtool/main.cc
+++ b/src/tools/flashtool/main.cc
@@ -14,7 +14,7 @@
#include "src/vm/program_relocator.h"
#include "src/vm/snapshot.h"
-namespace fletch {
+namespace dartino {
static void printUsage(char* name) {
printf(
@@ -83,7 +83,7 @@ static int Main(int argc, char** argv) {
return 0;
}
-} // namespace fletch
+} // namespace dartino
-// Forward main calls to fletch::Main.
-int main(int argc, char** argv) { return fletch::Main(argc, argv); }
+// Forward main calls to dartino::Main.
+int main(int argc, char** argv) { return dartino::Main(argc, argv); }

Powered by Google App Engine
This is Rietveld 408576698